@@ -1,11 +1,15 @@
+use std::fmt::Debug;
+
+use serde::{Deserialize, Serialize};
+
+#[cfg(feature = "non_critical_lints")]
+use crate::rules::non_critical_lints::dot_notation::DotNotationConfig;
 #[cfg(feature = "non_critical_lints")]
 use crate::rules::non_critical_lints::no_console::NoConsoleConfig;
 #[cfg(feature = "non_critical_lints")]
 use crate::rules::non_critical_lints::prefer_regex_literals::PreferRegexLiteralsConfig;
 #[cfg(feature = "non_critical_lints")]
 use crate::rules::non_critical_lints::quotes::QuotesConfig;
-use serde::{Deserialize, Serialize};
-use std::fmt::Debug;
 
 #[derive(Debug, Clone, Copy, Serialize, Deserialize)]
 #[serde(rename_all = "lowercase")]
@@ -57,6 +61,10 @@ pub struct LintConfig {
     #[serde(default)]
     pub no_debugger: RuleConfig<()>,
 
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default)]
+    pub dot_notation: RuleConfig<DotNotationConfig>,
+
     #[cfg(feature = "non_critical_lints")]
     #[serde(default)]
     pub quotes: RuleConfig<QuotesConfig>,
